@@ -1,7 +1,8 @@
 ;;; api.scm  --  The style for documenting Scheme APIs.
 ;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2006, 2007, 2008, 2009, 2012  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2008, 2009, 2012,
+;;;   2015 Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
@@ -271,7 +272,7 @@ def @SkribiloExample named @Title {} right x {
 		    %skribilo-module-reader)))
       (if (not (string? f))
 	  (skribe-error 'api-search-definition
-			(format #f "can't find source file `~a' in path"
+			(format #f "can't find source file '~a' in path"
 				file)
 			path)
 	  (with-input-from-file f
@@ -281,7 +282,7 @@ def @SkribiloExample named @Title {} right x {
 		   (if (eof-object? exp)
 		       (skribe-error 'api-search-definition
 				     (format #f
-					     "can't find `~a' definition" id)
+					     "can't find '~a' definition" id)
 				     file)
 		       (or (pred id exp) (loop (read))))))))))
 
@@ -379,7 +380,7 @@ def @SkribiloExample named @Title {} right x {
        '())
       (else
        (skribe-error 'define-markup-formals
-		     "Illegal `define-markup' form"
+		     "Invalid 'define-markup' form"
 		     def))))
 
 ;*---------------------------------------------------------------------*/
@@ -402,7 +403,7 @@ def @SkribiloExample named @Title {} right x {
        '((ident #f) (class #f)))
       (else
        (skribe-error 'define-markup-options
-		     "Illegal `define-markup' form"
+		     "Invalid 'define-markup' form"
 		     def))))
 
 ;*---------------------------------------------------------------------*/
@@ -412,7 +413,7 @@ def @SkribiloExample named @Title {} right x {
 ;*---------------------------------------------------------------------*/
 (define (define-markup-rest def)
    (match def
-      ((_ (args ___) _)
+      ((_ (args ___) _ ...)
        (if (not (pair? args))
 	   args
 	   (let ((l (last-pair args)))
@@ -423,7 +424,7 @@ def @SkribiloExample named @Title {} right x {
 			 (if (or (not (pair? (cdr rest)))
 				 (not (symbol? (cadr rest))))
 			     (skribe-error 'define-markup-rest
-					   "Illegal `define-markup' form"
+					   "Invalid 'define-markup' form"
 					   def)
 			     (cadr rest))
 			 #f))))))
@@ -433,7 +434,7 @@ def @SkribiloExample named @Title {} right x {
        'node)
       (else
        (skribe-error 'define-markup-rest
-		     "Illegal `define-markup' form"
+		     "Invalid 'define-markup' form"
 		     def))))
 
 ;*---------------------------------------------------------------------*/
@@ -826,7 +827,7 @@ def @SkribiloExample named @Title {} right x {
           (resolve (lambda (n e env)
                      (cond
                       ((engine-format? "latex" e)
-                       (skribe-warning 3 "`doc-engine' not rendered in LaTeX")
+                       (skribe-warning 3 "'doc-engine' not rendered in LaTeX")
                        #f)
                       ((engine-format? "lout" e)
                        (list (map (lambda (c)
