@@ -2,7 +2,7 @@
 ;;;
 ;;; Copyright 2003, 2004, 2009  Erick Gallesio - I3S-CNRS/ESSI <eg@unice.fr>
 ;;; Copyright 2003, 2004  Manuel Serrano
-;;; Copyright 2005, 2006, 2007, 2012  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2012, 2013, 2015  Ludovic Courts <ludo@gnu.org>
 ;;;
 ;;;
 ;;; This file is part of Skribilo.
@@ -29,8 +29,7 @@
   :use-module (srfi srfi-35)
   :use-module (skribilo condition)
   :use-module (skribilo utils syntax)
-
-  :autoload (skribilo location) (location?)
+  :use-module (skribilo location)
 
   :use-module (ice-9 match)
   :use-module (ice-9 optargs)
@@ -151,7 +150,7 @@
 	       (option (markup-unknown-option-error:option c)))
            (show-location markup)
 	   (format (current-error-port)
-		   (_ "~a: unknown markup option for `~a'~%")
+		   (_ "~a: unknown markup option for '~a'~%")
 		   option markup)))
 
 	((markup-already-bound-error? c)
@@ -159,7 +158,7 @@
 	       (ident  (markup-already-bound-error:ident  c)))
            (show-location markup)
 	   (format (current-error-port)
-		   (_ "`~a' (~a): markup identifier already bound~%")
+		   (_ "'~a' (~a): markup identifier already bound~%")
 		   ident
 		   (if (markup? markup)
 		       (markup-markup markup)
@@ -198,10 +197,7 @@
 
 
 (define (ast->file-location ast)
-   (let ((l (ast-loc ast)))
-     (if (location? l)
-	 (format #f "~a:~a:" (location-file l) (location-line l))
-	 "")))
+  (location->string (ast-loc ast)))
 
 (define-generic ast->string)
 
@@ -437,7 +433,7 @@
 ;;   (let ((e (or engine (use-engine))))
 ;;     (cond
 ;;       ((not (is-a? e <engine>))
-;;           (skribe-error 'markup-writer "illegal engine" e))
+;;           (skribe-error 'markup-writer "invalid engine" e))
 ;;       ((and (not before)
 ;;	    (not action)
 ;;	    (not after))
@@ -496,7 +492,7 @@
   (let ((ident (if (null? ident) (markup-ident node) (car ident))))
     (if ident
 	(let ((handle (hash-get-handle (document-node-table doc) ident)))
-	  ;;(format (current-error-port) "binding `~a' in `~a'~%" ident node)
+	  ;;(format (current-error-port) "binding '~a' in '~a'~%" ident node)
 	  (if (and (pair? handle) (not (eq? (cdr handle) node)))
 	      (raise (condition (&markup-already-bound-error
 				 (ident  ident)
