@@ -1,7 +1,7 @@
 ;;; template.scm  --  Template system for bibliography entries.
 ;;;
 ;;; Copyright 2003, 2004  Manuel Serrano
-;;; Copyright 2006, 2007  Ludovic Courts <ludovic.courtes@laas.fr>
+;;; Copyright 2006, 2007, 2015 Ludovic Courts <ludo@gnu.org>
 ;;;
 ;;;
 ;;; This file is part of Skribilo.
@@ -144,23 +144,26 @@
 
 (define (make-bib-entry-template/default kind)
   ;; The default bibliography entry template.
+
   (case kind
     ((techreport)
      `(author ". " (or title url documenturl) ". "
+              ;; TRANSLATORS: The next few msgids are fragments of
+              ;; bibliography items.
               ,(_ "Technical Report") " " number
               (", " institution)
               (", " address)
               (", " month) " " year
               (", pp. " pages) "."))
     ((article)
-     '(author ". " (or title url documenturl) ". "
-              "In " journal ", " volume
+     `(author ". " (or title url documenturl) ". "
+              ,(_ "In ") journal ", " volume
               ("(" number ") ")", "
               (address ", ") month " " year ", "
               ("pp. " pages) "."))
     ((inproceedings)
-     '(author ". " (or title url documenturl) ". "
-              "In " booktitle ", "
+     `(author ". " (or title url documenturl) ". "
+              ,(_ "In ") booktitle ", "
               (series ", ")
               ("(" number ")")
               ("pp. " pages ", ")
@@ -176,7 +179,7 @@
               (", pp. " pages) "."))
     ((inbook)
      `(author ". " (or title url documenturl) ". "
-              "In " booktitle ", " publisher
+              ,(_ "In ") booktitle ", " publisher
               (", " editor " (" ,(_ "editor") ")")
               (", " ,(_ "Chapter ") chapter)
               (", pp. " pages) ", "
