@@ -1,36 +1,33 @@
 ;;; engine.scm	-- Skribilo engines.
+;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2007, 2008  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2007, 2008, 2009, 2010  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Erick Gallesio - I3S-CNRS/ESSI <eg@essi.fr>
 ;;;
 ;;;
-;;; This program is free software; you can redistribute it and/or modify
+;;; This file is part of Skribilo.
+;;;
+;;; Skribilo is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; This program is distributed in the hope that it will be useful,
+;;; Skribilo is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo engine)
   :use-module (skribilo debug)
   :use-module (skribilo utils syntax)
-  :use-module ((skribilo lib) :select (%procedure-arity))
   :use-module (skribilo condition)
 
-  ;; `(skribilo writer)' depends on this module so it needs to be loaded
-  ;; after we defined `<engine>' and the likes.
-  :autoload (skribilo writer) (<writer>)
-
   :use-module (oop goops)
   :use-module (ice-9 optargs)
+  :use-module (ice-9 format)
 
   :autoload   (srfi srfi-34)  (raise guard)
   :use-module (srfi srfi-35)
@@ -43,7 +40,7 @@
 	   default-engine default-engine-set!
 	   make-engine copy-engine find-engine lookup-engine
 	   engine-custom engine-custom-set! engine-custom-add!
-	   engine-format? engine-add-writer!
+	   engine-format?
 	   processor-get-engine
 	   push-default-engine pop-default-engine
 
@@ -54,7 +51,7 @@
            unknown-engine-error:engine-name))
 
 
-(fluid-set! current-reader %skribilo-module-reader)
+(skribilo-module-syntax)
 
 
 ;;;
@@ -149,6 +146,12 @@
 (define (engine-symbol-table obj)
   (slot-ref obj 'symbol-table))
 
+(define-method (write (e <engine>) (p <port>))
+  (format p "#<~a ~a ~x>"
+          (class-name (class-of e))
+          (engine-ident e)
+          (object-address e)))
+
 
 
 ;;;
@@ -274,8 +277,14 @@
 (define (engine-loaded? id)
   "Check whether engine @var{id} is already loaded."
   ;; Trick taken from `resolve-module' in `boot-9.scm'.
-  (nested-ref the-root-module
-	      `(%app modules ,@(engine-id->module-name id))))
+  (cond-expand (guile-2
+                (nested-ref-module (resolve-module '() #f)
+                                   (engine-id->module-name id)))
+               (else
+                ;; This method works for 1.8 but is deprecated in 1.9/2.0 and
+                ;; doesn't work with 1.9.11 anyway.
+                (nested-ref the-root-module
+                            `(%app modules ,@(engine-id->module-name id))))))
 
 ;; A mapping of engine names to hooks.
 (define %engine-load-hook (make-hash-table))
@@ -349,83 +358,22 @@ otherwise the requested engine is returned."
 
 (define (engine-custom-add! e id val)
    (let ((old (engine-custom e id)))
-      (if (unspecified? old)
+      (if (eq? old 'unspecified)
 	  (engine-custom-set! e id (list val))
 	  (engine-custom-set! e id (cons val old)))))
 
-(define (engine-add-writer! e ident pred upred opt before action
-			    after class valid)
-  ;; Add a writer to engine E.  If IDENT is a symbol, then it should denote
-  ;; a markup name and the writer being added is specific to that markup.  If
-  ;; IDENT is `#t' (for instance), then it is assumed to be a ``free writer''
-  ;; that may apply to any kind of markup for which PRED returns true.
-
-  (define (check-procedure name proc arity)
-    (if (or (not (procedure? proc))
-            (not (equal? (%procedure-arity proc) arity)))
-        (raise (condition (&invalid-argument-error
-                           (proc-name 'engine-add-writer!)
-                           (argument  proc))))
-        #t))
-
-  (define (check-output name proc)
-    (and proc (or (string? proc) (check-procedure name proc 2))))
-
-  ;;
-  ;; Engine-add-writer! starts here
-  ;;
-  (or (engine? e)
-      (raise (condition (&invalid-argument-error
-                         (proc-name 'engine-add-writer!)
-                         (argument  e)))))
-
-  ;; check the options
-  (or (eq? opt 'all) (list? opt)
-      (raise (condition (&invalid-argument-error
-                         (proc-name 'engine-add-writer!)
-                         (argument  opt)))))
-
-  ;; check the correctness of the predicate
-  (if pred
-      (check-procedure "predicate" pred 2))
-
-  ;; check the correctness of the validation proc
-  (if valid
-      (check-procedure "validate" valid 2))
-
-  ;; check the correctness of the three actions
-  (check-output "before" before)
-  (check-output "action" action)
-  (check-output "after" after)
-
-  ;; create a new writer and bind it
-  (let ((n (make <writer>
-	     :ident (if (symbol? ident) ident 'all)
-	     :class class :pred pred :upred upred :options opt
-	     :before before :action action :after after
-	     :validate valid)))
-    (if (symbol? ident)
-	(let ((writers (slot-ref e 'writers)))
-	  (hashq-set! writers ident
-		      (cons n (hashq-ref writers ident '()))))
-	(slot-set! e 'free-writers
-		   (cons n (slot-ref e 'free-writers))))
-    n))
-
 
 
 ;;;
 ;;; Current engine.
 ;;;
 
-;; At this point, we're almost done with the bootstrap process.
-
 (define *current-engine*
-  ;; By default, use the HTML engine.
-  (make-parameter (lookup-engine 'html)
+  (make-parameter #f
 		  (lambda (val)
 		    (cond ((symbol? val) (lookup-engine val))
 			  ((engine? val) val)
+                          ((not val)     val)
 			  (else
 			   (raise (condition (&invalid-argument-error
                                               (proc-name '*current-engine*)
