@@ -39,6 +39,7 @@
   :autoload   (skribilo sui)           (document-sui)
   :autoload   (ice-9 rdelim)           (read-line)
   :autoload   (ice-9 regex)            (regexp-substitute/global)
+  :use-module (ice-9 match)
 
   :use-module (srfi srfi-1)
   :use-module (srfi srfi-13)
@@ -727,7 +728,7 @@
 	  (id (markup-ident n)))
       (unless (string? id)
 	 (skribe-error '&html-generic-header
-		       (format #f "Illegal identifier `~a'" id)
+		       (format #f "Invalid identifier '~a'" id)
 		       n))
       ;; title
       (output (new markup
@@ -942,18 +943,22 @@
 		    (let loop ((fns footnotes))
 		       (if (pair? fns)
 			   (let ((fn (car fns)))
-			      (format #t "<a name=\"footnote-~a\">"
+                              (display "\n<div class=\"footnote\">")
+
+                              ;; Note: the <a> tags must not be nested.
+			      (format #t "<a name=\"footnote-~a\"></a>"
 				      (string-canonicalize
 				       (container-ident fn)))
                               (format #t "<a href=\"#footnote-site-~a\">"
                                       (string-canonicalize
                                        (container-ident fn)))
-			      (format #t "<sup><small>~a</small></sup></a></a> "
-				      (markup-option fn :label))
+                              (format #t "<sup><small>~a</small></sup></a>"
+                                      (markup-option fn :label))
 			      (output (markup-body fn) e)
-			      (display "\n<br>\n")
+
+			      (display "\n</div>\n")
 			      (loop (cdr fns)))))
-		    (display "<div>")))))
+		    (display "</div>")))))
 
 ;*---------------------------------------------------------------------*/
 ;*    html-title-authors ...                                           */
@@ -1089,7 +1094,7 @@
 			(f (html-file c e)))
 		    (unless (string? id)
 		       (skribe-error 'toc
-				     (format #f "illegal identifier `~a'" id)
+				     (format #f "invalid identifier '~a'" id)
 				     c))
 		    (display " <tr>")
 		    ;; blank columns
@@ -1122,7 +1127,7 @@
 			     b)))
 		 (if (not (container? bb))
 		     (error 'toc
-			    "Illegal body (container expected)"
+			    "Invalid body (container expected)"
 			    (if (markup? bb)
 				(markup-markup bb)
 				"???"))
@@ -1146,22 +1151,11 @@
 
 			  (display "</tbody>\n</table>\n")))))))
 
-(define (section-in-separate-file? n e)
-  ;; Return true if N, a node (chapter, section, etc.), is to be put in a
-  ;; separate file, according to the customs of engine E.
-  (and (container? n)
-       (not (document? n))
-       (or (markup-option n :file)
-           (let ((kind (markup-markup n)))
-             (engine-custom e (string->symbol
-                               (string-append (symbol->string kind)
-                                              "-file")))))))
-
-(define (section-in-current-file? n e)
-  ;; Return true if N is to be output in the current file, or in the main
-  ;; file.
-  (and (container? n)
-       (not (section-in-separate-file? n e))))
+(define (sections-in-same-file? n1 n2 e)
+  ;; Return #t when N1 and N2 are to be output in the same file according to
+  ;; E's settings.
+  (and (container? n1) (container? n2)
+       (equal? (html-file n1 e) (html-file n2 e))))
 
 ;*---------------------------------------------------------------------*/
 ;*    &html-generic-document ...                                       */
@@ -1205,20 +1199,22 @@
 		     (body
                       ;; Collect the footnotes of all the sub-containers that
                       ;; are to be output in the same file.
-                      (let ((subsections
-                             (find-down (lambda (s)
-                                          (section-in-current-file? s e))
-                                        n)))
-                        (reverse
-                         (let loop ((subsections (cons n subsections))
-                                    (footnotes   '()))
-                           (cond ((pair? subsections)
-                                  (fold loop footnotes subsections))
-                                 ((null? subsections)
-                                  footnotes)
-                                 (else
-                                  (container-env-get subsections
-                                                     'footnote-env)))))))))
+                      (match (find-down (lambda (s)
+                                          (sections-in-same-file? s n e))
+                                        n)
+                        ((containers ...)
+                         (reverse
+                          (let loop ((subsections containers)
+                                     (footnotes   '()))
+                            (match subsections
+                              ((subsections ...)
+                               (fold loop footnotes subsections))
+                              (container
+                               (append footnotes
+                                       (or (container-env-get container
+                                                              'footnote-env)
+                                           '())))))))
+                        (_ #f)))))
 	  (page (new markup
 		   (markup '&html-page)
 		   (ident (string-append id "-page"))
@@ -1574,7 +1570,7 @@
 		  (display "width=\"100%\" cellpadding=\"0\" cellspacing=\"0\" border=\"0\"><tr><td align=\"right\">"))
 		 (else
 		  (skribe-error 'flush
-				"Illegal side"
+				"Invalid side"
 				(markup-option n :side)))))
    :after (lambda (n e)
 	     (case (markup-option n :side)
@@ -1834,7 +1830,7 @@
 						     efmt
 						     '("gif" "jpg" "png"))))))
 		 (if (not (string? img))
-		     (skribe-error 'html "Illegal image" file)
+		     (skribe-error 'html "Invalid image" file)
 		     (begin
 			(format #t "<img src=\"~a\" border=\"0\"" img)
 			(html-class n)
