@@ -1,7 +1,7 @@
 ;;; info.scm  --  GNU Info engine.
 ;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2008, 2009, 2012  Ludovic Courtès <ludo@gnu.org>
+;;; Copyright 2008, 2009, 2012, 2015  Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright 2001, 2002  Manuel Serrano
 ;;;
 ;;;
@@ -83,6 +83,7 @@
 ;*    info-node ...                                                    */
 ;*---------------------------------------------------------------------*/
 (define (info-node node next prev up)
+   ;; info "(info) Expert Info"
    (print "\n")
    (format #t "File: ~a,  Node: ~a,  ~:[~*~;Next: ~a,  ~]~:[~*~;Prev: ~a,  ~]Up: ~a~%"
            (info-dest) node next next prev prev up))
@@ -173,7 +174,7 @@
                   (begin
                     (skribe-warning/ast 1 section
                                         (format #f
-                                                (_ "Info node title `~A' already used")
+                                                (_ "Info node title '~A' already used")
                                                 title))
                     (skribe-warning/ast 1 (cdr same-named)
                                         (_ "previous occurrence was here"))
@@ -222,6 +223,7 @@
                                  footnotes)
                        ))))
               ;; FIXME: Handle `:ending'.
+              ;; TODO: Emit a tag table (info "(info) Tags").
               )))
 
 ;*---------------------------------------------------------------------*/
@@ -804,7 +806,7 @@
               (string? (markup-option n :file)))
   :action (lambda (n e)
             (if (markup-option n :url)
-                (skribe-warning/ast 1 n (_ "image URLs not supported"))
+                (skribe-warning/ast 1 n (_ "image URLs are not supported"))
                 (let ((f (let ((f (markup-option n :file)))
                            (convert-image f '("png" "gif" "jpg"))))
                       (h (markup-option n :height))
