@@ -2,7 +2,7 @@
 ;;; -*- coding: iso-8859-1 -*-
 ;;;
 ;;; Copyright 2003, 2004  Manuel Serrano
-;;; Copyright 2007  Ludovic Courts <ludo@chbouib.org>
+;;; Copyright 2007, 2013  Ludovic Courts <ludo@gnu.org>
 ;;;
 ;;;
 ;;; This file is part of Skribilo.
@@ -25,10 +25,10 @@
   :use-module (skribilo engine)
   :use-module (skribilo writer)
   :autoload   (skribilo output)         (output)
-  :autoload   (skribilo package base)   (chapter font flush
-                                         toc the-bibliography)
+  :use-module (skribilo package base)
   :autoload   (skribilo utils keywords) (the-options the-body)
   :autoload   (skribilo evaluator)      (evaluate-document)
+  :autoload   (skribilo biblio author)  (bib-sort/first-author-last-name)
 
   :use-module (skribilo lib)
   :use-module (skribilo utils syntax)
@@ -53,12 +53,12 @@
    (markup-writer '&latex-author le
       :before (lambda (n e)
 		 (let ((body (markup-body n)))
-		    (format #f "\\numberofauthors{~a}\n\\author{\n"
+		    (format #t "\\numberofauthors{~a}\n\\author{\n"
 			    (if (pair? body) (length body) 1))))
       :action (lambda (n e)
 		 (let ((body (markup-body n)))
 		    (for-each (lambda (a)
-				 (display "\\alignauthor\n")
+                                 (display "\\alignauthor\n")
 				 (output a e))
 			      (if (pair? body) body (list body)))))
       :after "}\n")
@@ -181,13 +181,13 @@
       (if (string? old)
 	  (engine-custom-set! le 'predocument (string-append cop old))
 	  (engine-custom-set! le 'predocument cop))))
-   
+
 ;*---------------------------------------------------------------------*/
 ;*    references ...                                                   */
 ;*---------------------------------------------------------------------*/
 (define (references)
    (list "\n\n"
-	 (if (engine-format? "latex")
-	     (font :size -1 (flush :side 'left (the-bibliography)))
-	     (section :title "References"
-                      (font :size -1 (the-bibliography))))))
+	 (chapter :title "References"
+                  (flush :side 'left
+                         (the-bibliography
+                          :sort bib-sort/first-author-last-name)))))
