@@ -1,7 +1,7 @@
 ;;; base.scm -- The base markup package of Skribe/Skribilo.
 ;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2006, 2007, 2008, 2009  Ludovic Courts  <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2008, 2009, 2013, 2015 Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
@@ -27,6 +27,8 @@
 
   :use-module (skribilo ast)
   :use-module (skribilo resolve)
+  :use-module (skribilo location)
+  :use-module (skribilo condition)
   :use-module (skribilo utils keywords)
   :autoload   (srfi srfi-1)        (every any filter)
   :autoload   (skribilo evaluator) (include-document)
@@ -62,9 +64,9 @@
 ;*    include ...                                                      */
 ;*---------------------------------------------------------------------*/
 (define-public (include file)
-   (if (not (string? file))
-       (skribe-error 'include "Illegal file (string expected)" file)
-       (include-document file)))
+  (unless (string? file)
+    (invalid-argument-error 'include file 'file))
+  (include-document file))
 
 ;*---------------------------------------------------------------------*/
 ;*    document ...                                                     */
@@ -121,18 +123,18 @@
 		       (phone #f)
 		       (photo #f)
 		       (align 'center))
-   (if (not (memq align '(center left right)))
-       (skribe-error 'author "Illegal align value" align)
-       (new container
-	  (markup 'author)
-	  (ident (or ident (symbol->string (gensym "author"))))
-	  (class class)
-          (loc   &invocation-location)
-	  (required-options '(:name :title :affiliation :email :url :address :phone :photo :align))
-	  (options `((:name ,name)
-		     (:align ,align)
-		     ,@(the-options opts :ident :class)))
-	  (body #f))))
+   (unless (memq align '(center left right))
+     (invalid-argument-error 'author align 'align))
+   (new container
+        (markup 'author)
+        (ident (or ident (symbol->string (gensym "author"))))
+        (class class)
+        (loc   &invocation-location)
+        (required-options '(:name :title :affiliation :email :url :address :phone :photo :align))
+        (options `((:name ,name)
+                   (:align ,align)
+                   ,@(the-options opts :ident :class)))
+        (body #f)))
 
 ;*---------------------------------------------------------------------*/
 ;*    handle ...                                                       */
@@ -142,7 +144,7 @@
    (let ((body (the-body opts)))
       (cond
 	 (section
-	  (error 'handle "Illegal handle `section' option" section)
+	  (error 'handle "Invalid handle 'section' option" section)
 	  (new unresolved
              (loc  &invocation-location)
 	     (proc (lambda (n e env)
@@ -157,7 +159,7 @@
              (loc &invocation-location)
 	     (ast (car body))))
 	 (else
-	  (skribe-error 'handle "Illegal handle" opts)))))
+          (invalid-argument-error 'handle opts)))))
 
 ;*---------------------------------------------------------------------*/
 ;*    toc ...                                                          */
@@ -190,13 +192,9 @@
 		  ((null? (cdr body))
 		   (if (handle? (car body))
 		       (car body)
-		       (skribe-error 'toc
-				     "Illegal argument (handle expected)"
-				     (if (markup? (car body))
-					 (markup-markup (car body))
-					 "???"))))
+                       (invalid-argument-error 'toc (car body))))
 		  (else
-		   (skribe-error 'toc "Illegal argument" body)))))))
+                   (invalid-argument-error 'toc body)))))))
 
 ;*---------------------------------------------------------------------*/
 ;*    section-number ...                                               */
@@ -381,9 +379,9 @@
 	 ((null? num)
 	  ln)
 	 ((not (null? (cdr num)))
-	  (skribe-error 'linebreak "Illegal arguments" num))
+          (invalid-argument-error 'linebreak num))
 	 ((not (and (integer? (car num)) (positive? (car num))))
-	  (skribe-error 'linebreak "Illegal argument" (car num)))
+          (invalid-argument-error 'linebreak (car num)))
 	 (else
 	  (vector->list (make-vector (car num) ln))))))
 
@@ -483,7 +481,7 @@
 	  (options (the-options opts :ident :class))
 	  (body (the-body opts))))
       (else
-       (skribe-error 'flush "Illegal side" side))))
+       (invalid-argument-error 'flush side 'side))))
 
 ;*---------------------------------------------------------------------*/
 ;*    center ...                                                       */
@@ -508,16 +506,16 @@
 		     :key
 		     (ident #f) (class "prog")
 		     (line 1) (linedigit #f) (mark ";!"))
-   (if (not (or (string? mark) (eq? mark #f)))
-       (skribe-error 'prog "Illegal mark" mark)
-       (new container
-	  (markup 'prog)
-	  (ident (or ident (symbol->string (gensym "prog"))))
-	  (class class)
-          (loc   &invocation-location)
-	  (required-options '(:line :mark))
-	  (options (the-options opts :ident :class :linedigit))
-	  (body (make-prog-body (the-body opts) line linedigit mark)))))
+   (unless (or (string? mark) (eq? mark #f))
+     (invalid-argument-error 'prog mark 'mark))
+   (new container
+        (markup 'prog)
+        (ident (or ident (symbol->string (gensym "prog"))))
+        (class class)
+        (loc   &invocation-location)
+        (required-options '(:line :mark))
+        (options (the-options opts :ident :class :linedigit))
+        (body (make-prog-body (the-body opts) line linedigit mark))))
 
 ;*---------------------------------------------------------------------*/
 ;*    source ...                                                       */
@@ -537,34 +535,36 @@
       (cond
 	 ((and (not (null? body)) (or file start stop definition))
 	  (skribe-error 'source
-			"file, start/stop, and definition are exclusive with body"
+			(_ "file, start/stop, and definition\
+ cannot be combined with body")
 			body))
 	 ((and start stop definition)
 	  (skribe-error 'source
-			"start/stop are exclusive with a definition"
+			(_ "start/stop are exclusive with a definition")
 			body))
 	 ((and (or start stop definition) (not file))
 	  (skribe-error 'source
-			"start/stop and definition require a file specification"
+			(_ "start/stop and definition require a\
+ file specification")
 			file))
 	 ((and definition (not language))
 	  (skribe-error 'source
-			"definition requires a language specification"
+			(_ "definition requires a language specification")
 			definition))
 	 ((and file (not (string? file)))
-	  (skribe-error 'source "Illegal file" file))
+          (invalid-argument-error 'source file 'file))
 	 ((and start (not (or (integer? start) (string? start))))
-	  (skribe-error 'source "Illegal start" start))
+          (invalid-argument-error 'source start 'start))
 	 ((and stop (not (or (integer? stop) (string? stop))))
-	  (skribe-error 'source "Illegal start" stop))
+          (invalid-argument-error 'source stop 'stop))
 	 ((and (integer? start) (integer? stop) (> start stop))
 	  (skribe-error 'source
-			"start line > stop line"
+			(_ "start line is greater than stop line")
 			(format #f "~a/~a" start stop)))
 	 ((and language (not (language? language)))
-	  (skribe-error 'source "illegal language" language))
+          (invalid-argument-error 'source language 'language))
 	 ((and tab (not (integer? tab)))
-	  (skribe-error 'source "illegal tab" tab))
+          (invalid-argument-error 'source tab 'tab))
 	 (file
 	  (let ((s (if (not definition)
 		       (source-read-lines file start stop tab)
@@ -585,7 +585,7 @@
 ;*---------------------------------------------------------------------*/
 (define-markup (language :key name (fontifier #f) (extractor #f))
    (if (not (string? name))
-       (skribe-type-error 'language "illegal name" name "string")
+       (skribe-type-error 'language "invalid name" name "string")
        (new language
 	  (name name)
 	  (fontifier fontifier)
@@ -651,7 +651,7 @@
 		 (if (not (is-markup? r markup))
 		     (skribe-warning 2
 				     for
-				     (format #f "illegal `~a' element, `~a' expected"
+				     (format #f "invalid '~a' element, '~a' expected"
 					     (if (markup? r)
 						 (markup-markup r)
 						 (type-name r))
@@ -701,19 +701,19 @@
 ;*    item ...                                                         */
 ;*---------------------------------------------------------------------*/
 (define-markup (item :rest opts :key (ident #f) (class #f) key)
-   (if (and key (not (or (string? key)
-			 (number? key)
-			 (markup? key)
-			 (pair? key))))
-       (skribe-type-error 'item "Illegal key:" key "node")
-       (new container
-	  (markup 'item)
-	  (ident (or ident (symbol->string (gensym "item"))))
-	  (class class)
-          (loc   &invocation-location)
-	  (required-options '(:key))
-	  (options `((:key ,key) ,@(the-options opts :ident :class :key)))
-	  (body (the-body opts)))))
+   (when (and key (not (or (string? key)
+                           (number? key)
+                           (markup? key)
+                           (pair? key))))
+     (invalid-argument-error 'item key 'key))
+   (new container
+        (markup 'item)
+        (ident (or ident (symbol->string (gensym "item"))))
+        (class class)
+        (loc   &invocation-location)
+        (required-options '(:key))
+        (options `((:key ,key) ,@(the-options opts :ident :class :key)))
+        (body (the-body opts))))
 
 ;*---------------------------------------------------------------------*/
 ;*    table                                                            */
@@ -745,19 +745,13 @@
 	 (cells-vals '(collapse separate)))
       (cond
 	 ((and frame (not (memq frame frame-vals)))
-	  (skribe-error 'table
-			(format #f "frame should be one of \"~a\"" frame-vals)
-			frame))
+          (invalid-argument-error 'table frame 'frame))
 	 ((and rules (not (memq rules rules-vals)))
-	  (skribe-error 'table
-			(format #f "rules should be one of \"~a\"" rules-vals)
-			rules))
+          (invalid-argument-error 'table rules 'rules))
 	 ((not (or (memq cellstyle cells-vals)
 		   (string? cellstyle)
 		   (number? cellstyle)))
-	  (skribe-error 'table
-			(format #f "cellstyle should be one of \"~a\", or a number, or a string" cells-vals)
-			cellstyle))
+          (invalid-argument-error 'table cellstyle 'cellstyle))
 	 (else
 	  (new container
 	     (markup 'table)
@@ -806,19 +800,13 @@
 		     valign)))
       (cond
 	 ((not (integer? colspan))
-	  (skribe-type-error 'tc "Illegal colspan, " colspan "integer"))
+          (invalid-argument-error 'tc colspan 'colspan))
 	 ((not (symbol? align))
-	  (skribe-type-error 'tc "Illegal align, " align "align"))
+          (invalid-argument-error 'tc align 'align))
 	 ((not (memq align '(#f center left right)))
-	  (skribe-error
-	   'tc
-	   "align should be one of 'left', `center', or `right'"
-	   align))
+          (invalid-argument-error 'tc align 'align))
 	 ((not (memq valign '(#f top middle center bottom)))
-	  (skribe-error
-	   'tc
-	   "valign should be one of 'top', `middle', `center', or `bottom'"
-	   valign))
+          (invalid-argument-error 'tc valign 'valign))
 	 (else
 	  (new container
 	     (markup 'tc)
@@ -923,7 +911,7 @@
       ((and (string? char) (= (string-length char) 1))
        char)
       (else
-       (skribe-error 'char "Illegal char" char))))
+       (invalid-argument-error 'char char))))
 
 ;*---------------------------------------------------------------------*/
 ;*    symbol ...                                                       */
@@ -935,9 +923,7 @@
 	    ((string? symbol)
 	     symbol)
 	    (else
-	     (skribe-error 'symbol
-			   "Illegal argument (symbol expected)"
-			   symbol)))))
+             (invalid-argument-error 'symbol symbol)))))
     (new markup
 	 (markup 'symbol)
          (loc    &invocation-location)
@@ -947,12 +933,12 @@
 ;*    ! ...                                                            */
 ;*---------------------------------------------------------------------*/
 (define-markup (! format :rest node)
-   (if (not (string? format))
-       (skribe-type-error '! "Illegal format:" format "string")
-       (new command
-          (loc &invocation-location)
-	  (fmt format)
-	  (body node))))
+   (unless (string? format)
+     (invalid-argument-error '! format))
+   (new command
+        (loc &invocation-location)
+        (fmt format)
+        (body node)))
 
 ;*---------------------------------------------------------------------*/
 ;*    processor ...                                                    */
@@ -961,9 +947,9 @@
 			  :key (combinator #f) (engine #f) (procedure #f))
    (cond
       ((and combinator (not (procedure? combinator)))
-       (skribe-error 'processor "Combinator not a procedure" combinator))
+       (invalid-argument-error 'processor combinator 'combinator))
       ((and engine (not (engine? engine)))
-       (skribe-error 'processor "Illegal engine" engine))
+       (invalid-argument-error 'processor engine 'engine))
       ((and procedure
 	    (or (not (procedure? procedure))
 		(not (let ((a (procedure-property procedure 'arity)))
@@ -973,7 +959,7 @@
                                   (rest?      (caddr a)))
                               (or rest?
                                   (>= (+ compulsory optional) 2))))))))
-       (skribe-error 'processor "Illegal procedure" procedure))
+       (invalid-argument-error 'processor procedure 'procedure))
       (else
        (new processor
           (loc &invocation-location)
@@ -1022,9 +1008,9 @@
 	 ((null? bd)
 	  (skribe-error 'mark "Missing argument" '()))
 	 ((not (string? (car bd)))
-	  (skribe-type-error 'mark "Illegal ident:" (car bd) "string"))
+          (invalid-argument-error 'mark (car bd)))
 	 (ident
-	  (skribe-error 'mark "Illegal `ident:' option" ident))
+          (invalid-argument-error 'mark ident 'ident))
 	 (else
 	  (let* ((bs (ast->string bd))
 		 (n (new markup
@@ -1065,36 +1051,24 @@
 		    (skribe #f)
 		    (page #f)
                     (sort-bib-refs bib-sort-refs/number))
-   (define (unref ast text kind)
-      (let ((msg (format #f "can't find `~a': " kind)))
-	 (if (ast? ast)
-	     (begin
-		(skribe-warning/ast 1 ast 'ref msg text)
-		(new markup
-		   (markup 'unref)
-		   (ident (symbol->string (gensym "unref")))
-		   (class class)
-                   (loc   &invocation-location)
-		   (required-options '(:text))
-		   (options `((kind ,kind) ,@(the-options opts :ident :class)))
-		   (body (list text ": " (ast->file-location ast)))))
-	     (begin
-		(skribe-warning 1 'ref msg text)
-		(new markup
-		   (markup 'unref)
-		   (ident (symbol->string (gensym "unref")))
-		   (class class)
-                   (loc   &invocation-location)
-		   (required-options '(:text))
-		   (options `((kind ,kind) ,@(the-options opts :ident :class)))
-		   (body text))))))
+   (define (unref text kind)
+      (let ((msg (format #f "can't find '~a': " kind)))
+        (warning/loc 1 &invocation-location 'ref msg text)
+        (new markup
+             (markup 'unref)
+             (ident (symbol->string (gensym "unref")))
+             (class class)
+             (loc   &invocation-location)
+             (required-options '(:text))
+             (options `((kind ,kind) ,@(the-options opts :ident :class)))
+             (body (list text ": " (location->string &invocation-location))))))
    (define (skribe-ref skribe)
      (let* ((sui (load-sui skribe))
             (os  (the-options opts :skribe :class :text))
             (u   (sui-ref->url (dirname (search-path (*sui-path*) skribe))
                                sui ident os)))
        (if (not u)
-           (unref #f os 'sui-ref)
+           (unref os 'sui-ref)
            (ref :url u :text text :class class))))
    (define (handle-ref text)
       (new markup
@@ -1107,7 +1081,7 @@
 	 (body text)))
    (define (do-title-ref title kind)
       (if (not (string? title))
-	  (skribe-type-error 'ref "illegal reference" title "string")
+	  (skribe-type-error 'ref "invalid reference" title "string")
 	  (new unresolved
              (loc  &invocation-location)
 	     (proc (lambda (n e env)
@@ -1130,27 +1104,27 @@
 					   ,@(the-options opts :ident :class)))
 				(body (new handle
 					 (ast s))))
-			     (unref n title (or kind 'title)))))))))
+			     (unref title (or kind 'title)))))))))
    (define (do-ident-ref text kind)
-      (if (not (string? text))
-	  (skribe-type-error 'ref "Illegal reference" text "string")
-	  (new unresolved
-             (loc  &invocation-location)
-	     (proc (lambda (n e env)
-		      (let ((s (resolve-ident text kind n env)))
-			 (if s
-			     (new markup
-				(markup 'ref)
-				(ident (symbol->string (gensym "ident-ref")))
-				(class class)
-                                (loc   &invocation-location)
-				(required-options '(:text))
-				(options `((kind ,kind)
-					   (mark ,text)
-					   ,@(the-options opts :ident :class)))
-				(body (new handle
+      (unless (string? text)
+        (invalid-argument-error 'ref text))
+      (new unresolved
+           (loc  &invocation-location)
+           (proc (lambda (n e env)
+                   (let ((s (resolve-ident text kind n env)))
+                     (if s
+                         (new markup
+                              (markup 'ref)
+                              (ident (symbol->string (gensym "ident-ref")))
+                              (class class)
+                              (loc   &invocation-location)
+                              (required-options '(:text))
+                              (options `((kind ,kind)
+                                         (mark ,text)
+                                         ,@(the-options opts :ident :class)))
+                              (body (new handle
 					 (ast s))))
-			     (unref n text (or kind 'ident)))))))))
+                         (unref text (or kind 'ident))))))))
    (define (mark-ref mark)
      (do-ident-ref mark 'mark))
    (define (make-bib-ref v)
@@ -1169,8 +1143,7 @@
 		    (o (markup-option s 'used)))
 		(markup-option-add! s 'used (if (pair? o) (cons h o) (list h)))
 		n)
-	     (unref #f v 'bib)))) ; FIXME: This prevents source location info
-				  ; from being provided in the warning msg
+	     (unref v 'bib))))
    (define (bib-ref text)
       (if (pair? text)
 	  (new markup
@@ -1205,7 +1178,7 @@
 					,@(the-options opts :ident :class)))
 			     (body (new handle
 				      (ast l))))
-			  (unref n line 'line)))))))
+			  (unref line 'line)))))))
    (let ((b (the-body opts)))
       (if (not (null? b))
 	  (skribe-warning 1 'ref "Arguments ignored " b))
@@ -1222,7 +1195,7 @@
 	 (bib (bib-ref bib))
 	 (url (url-ref))
 	 (line (line-ref line))
-	 (else (skribe-error 'ref "illegal reference" opts)))))
+	 (else (invalid-argument-error 'ref opts)))))
 
 
 ;*---------------------------------------------------------------------*/
@@ -1242,7 +1215,7 @@
                  (cond
                   ((not target)
                    (skribe-warning/ast 1 n 'numref
-                                       "can't find `ident': "
+                                       "can't find 'ident': "
                                        ident)
                    (new markup
                         (markup 'unref)
@@ -1257,16 +1230,15 @@
                    ;; Loop until `number' is resolved.
                    n)
                   (else
-                   (let ((xref
-                          (ref :text
-                               (list (if text text "") " "
-                                     (if (number? number)
-                                         (markup-number-string target
-                                                               separator)
-                                         ""))
-                               :page page
-                               :handle (handle target))))
-                     (resolve! xref e env)))))))))
+                   (ref :text
+                        (list (if text text "")
+                              (if text (~) "")
+                              (if (number? number)
+                                  (markup-number-string target
+                                                        separator)
+                                  ""))
+                        :page page
+                        :handle (handle target)))))))))
 
 ;*---------------------------------------------------------------------*/
 ;*    resolve ...                                                      */
@@ -1292,7 +1264,7 @@
 		   ((pair? f)
 		    (bib-add! bib-table f))
 		   (else
-		    (skribe-error "bibliography" "Illegal entry" f))))
+                    (invalid-argument-error 'bibliography f))))
 	     (the-body files)))
 
 ;*---------------------------------------------------------------------*/
@@ -1310,27 +1282,25 @@
 				 (sort bib-sort/authors)
 				 (count 'partial)
                                  (labels 'number))
-   (if (not (memq count '(partial full)))
-       (skribe-error 'the-bibliography
-		     "count must be either `partial' or `full'"
-		     count)
-       (let ((label-proc (case labels
-                           ((number)    assign-entries-numbers!)
-                           ((name+year) assign-entries-name+years!)
-                           (else
-                            (skribe-error
-                             'the-bibliography
-                             "invalid label type" labels)))))
-         (new unresolved
-            (loc  &invocation-location)
-            (proc (lambda (n e env)
-                     (resolve-the-bib bib-table
-                                      (new handle (ast n))
-                                      sort
-                                      pred
-                                      count
-                                      (the-options opts)
-                                      label-proc)))))))
+   (unless (memq count '(partial full))
+     (invalid-argument-error 'the-bibliography count 'count))
+
+   (let ((label-proc (case labels
+                       ((number)    assign-entries-numbers!)
+                       ((name+year) assign-entries-name+years!)
+                       (else
+                        (invalid-argument-error 'the-bibliography
+                                                labels 'labels)))))
+     (new unresolved
+          (loc  &invocation-location)
+          (proc (lambda (n e env)
+                  (resolve-the-bib bib-table
+                                   (new handle (ast n))
+                                   sort
+                                   pred
+                                   count
+                                   (the-options opts)
+                                   label-proc))))))
 
 ;*---------------------------------------------------------------------*/
 ;*    noabbrev ...                                                     */
@@ -1365,17 +1335,12 @@
 		    ((and (pair? entry-name) (every string? entry-name))
 		     (string-concatenate entry-name))
 		    (else
-		     (skribe-error
-		      'index
-		      "entry-name must be either a string or a list of strings"
-		      entry-name))))
+                     (invalid-argument-error 'index entry-name))))
 	  (table (cond
 		    ((not index) (default-index))
 		    ((index? index) index)
-		    (else (skribe-type-error 'index
-					     "Illegal index table, "
-					     index
-					     "index"))))
+		    (else
+                     (invalid-argument-error 'index index 'index))))
 	  (m (mark (symbol->string (gensym "mark"))))
 	  (h (new handle (ast m)))
 	  (new (new markup
@@ -1419,13 +1384,12 @@
    (let ((bd (the-body opts)))
       (cond
 	 ((not (and (integer? char-offset) (>= char-offset 0)))
-	  (skribe-error 'the-index "Illegal char offset" char-offset))
+          (invalid-argument-error 'the-index char-offset 'char-offset))
 	 ((not (integer? column))
-	  (skribe-error 'the-index "Illegal column number" column))
+          (invalid-argument-error 'the-index column 'column))
 	 ((not (every index? bd))
-	  (skribe-error 'the-index
-			"Illegal indexes"
-			(filter (lambda (o) (not (index? o))) bd)))
+          (invalid-argument-error 'the-index
+                                  (filter (lambda (o) (not (index? o))) bd)))
 	 (else
 	  (new unresolved
              (loc  &invocation-location)
@@ -1486,9 +1450,9 @@
 			((roman) the-roman-number)
 			((arabic) the-arabic-number)
 			((alpha) the-alpha-number)
-			(else (skribe-error 'counter
-					    "Illegal numbering"
-					    numbering)))))
+			(else
+                         (invalid-argument-error 'counter
+                                                 numbering 'numbering)))))
       (let loop ((num 1)
 		 (items items)
 		 (res '()))
